:notoc:

==============
Knowledge base
==============

.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials/index
   troubleshooting/index

Welcome to Coiled's Knowledge base, this section of our documentation aims to
give you access to tutorials, getting started and troubleshooting articles.

Let's see how we can help you today

.. panels::
    :card: border-0
    :container: container-lg pb-3
    :column: col-md-6 col-md-6 p-2
    :body: text-center border-0
    :header: text-center border-0 h4 bg-white
    :footer: border-0 bg-white

    Tutorials
    ^^^^^^^^^

    Articles that will help you getting started with Coiled.

    +++

    .. link-button:: tutorials/index
        :type: ref
        :text: Tutorials
        :classes: btn-outline-primary btn-block stretched-link

    ---

    Troubleshooting
    ^^^^^^^^^^^^^^^^

    Articles that focus on troubleshooting common issues.

    +++

    .. link-button:: troubleshooting/index
        :type: ref
        :text: Troubleshooting
        :classes: btn-outline-primary btn-block stretched-link


Other ways to get help
----------------------

If you haven't found what you where looking for and need help with anything, you
can get support from Coiled by:

* `Joining our slack <https://join.slack.com/t/coiled-users/shared_invite/zt-hx1fnr7k-In~Q8ui3XkQfvQon0yN5WQ>`_
* `Create an issue on GitHub <https://github.com/coiled/feedback/issues/new>`_
* `E-mail us at support@coiled.io <mailto:support@coiled.io>`_
